## Summary

<!-- What does this PR do? 1-3 bullet points. -->

## Test Plan

<!-- How was this tested? List test files or commands. -->

- [ ] All existing tests pass (`python -m pytest tests/`)
- [ ] New tests added for new behavior
- [ ] Linting passes (`ruff check src/ tests/`)
- [ ] Type checking passes (`mypy src/`)
